import { Button, Space, Table } from "antd";
import Column from "antd/es/table/Column";
import { useEffect, useState } from "react";
import { useSelector } from "react-redux";
import { selectUserId } from "../../features/auth/authSlice";
import axiosInstance from "../../api/axios";

export default function LeaderApproval() {
  const [reservations, setReservations] = useState([]);
  const [pagination, setPagination] = useState({
    current: 1,
    pageSize: 10,
    total: 0,
  });

  const userId = useSelector(selectUserId);

  const fetchData = async (pagination) => {
    const data = await axiosInstance.get(`/reservation/leader/${userId}`, {
      params: {
        page: pagination.current,
        size: pagination.pageSize,
      },
    });
    console.log(data);

    setReservations(data.records);
    setPagination({
      ...pagination,
      total: data.total,
    });
  };

  useEffect(() => {
    fetchData(pagination);
  }, []);

  const handlePageChange = (pagination) => {
    fetchData(pagination);
  };

  const handleApproval = (reservationId, isApprove) => {
    console.log(reservationId);
    console.log(isApprove);
  };

  // "预约人、所属团队、联系方式、预约设备、预约时间： 设备详情、"
  return (
    <Table
      dataSource={reservations}
      pagination={pagination}
      rowKey="reservationId"
      onChange={handlePageChange}
    >
      <Column title="预约人" key="applicantName" dataIndex="applicantName" />
      <Column title="所属团队" key="applicantTeam" dataIndex="applicantTeam" />
      <Column
        title="联系方式"
        key="applicantContact"
        dataIndex="applicantContact"
      />
      <Column title="预约设备" key="deviceName" dataIndex="deviceName" />
      <Column title="开始时间" key="startTime" dataIndex="startTime" />
      <Column title="结束时间" key="endTime" dataIndex="endTime" />
      <Column
        title="操作"
        key="action"
        render={(_, record) => {
          return (
            <Space>
              <Button
                type="primary"
                size="small"
                onClick={() => handleApproval(record.reservationId, true)}
              >
                批准
              </Button>
              <Button
                color="danger"
                variant="solid"
                size="small"
                onClick={() => handleApproval(record.reservationId, false)}
              >
                拒绝
              </Button>
            </Space>
          );
        }}
      />
    </Table>
  );
}
